==> adfurikun-1.2.0.tar.gz: android/src/main/kotlin/jp/co/glossom/adfurikun/AdfurikunInterstitial.kt <==
package jp.co.glossom.adfurikun

import io.flutter.plugin.common.MethodChannel
import jp.tjkapp.adfurikunsdk.moviereward.*

/**
 * インタースティシャル
 */
internal class AdfurikunInterstitial(val number: Int, val appId: String, val channel: MethodChannel) {

    private var interstitial: AdfurikunInter? = null
    private var listener: AdfurikunInterListener? = null

    /**
     * 初期化
     */
    fun init() {
        if (AdfurikunPlugin.currentActivity != null) {
            interstitial = AdfurikunInter(appId, AdfurikunPlugin.currentActivity).apply {
                setAdfurikunInterListener(createListener)
                onResume()
            }
        }
    }

    /**
     * 読み込み
     */
    fun load() {
        interstitial?.load()
    }

    /**
     * 再生
     */
    fun play() {
        interstitial?.play()
    }

    /**
     * 準備判定
     * @param result
     */
    fun isPrepared(result: MethodChannel.Result) {
        result.success(interstitial?.isPrepared ?: false)
    }

    /**
     * 再開
     */
    fun resume() {
        interstitial?.onResume()
    }

    /**
     * 一時停止
     */
    fun pause() {
        interstitial?.onPause()
    }

    /**
     * 破棄
     */
    fun destroy() {
        interstitial?.onDestroy()
        interstitial = null
        listener = null
    }

    /**
     * リスナーを作成
     */
    private val createListener: AdfurikunInterListener?
        get() {
            listener ?: run {
                listener = object : AdfurikunInterListener {
                    override fun onPrepareSuccess(isManualMode: Boolean) {
                        channel.invokeMethod(Constants.ON_PREPARE_SUCCESS, AdfurikunCommons.getArgs(number = number, appId = appId))
                    }

                    override fun onPrepareFailure(error: AdfurikunMovieError?) {
                        channel.invokeMethod(Constants.ON_PREPARE_FAILURE, AdfurikunCommons.getArgs(number = number, appId = appId, errorCode = error?.errorCode ?: 0))
                    }

                    override fun onStartPlaying(data: InterData) {
                        channel.invokeMethod(Constants.ON_START_PLAYING, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onFinishedPlaying(data: InterData) {
                        channel.invokeMethod(Constants.ON_FINISHED_PLAYING, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onFailedPlaying(data: InterData) {
                        channel.invokeMethod(Constants.ON_FAILED_PLAYING, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onAdClose(data: InterData) {
                        channel.invokeMethod(Constants.ON_AD_CLOSE, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onStartShowing(data: InterData) {
                        // 処理なし
                    }

                    override fun onClick(data: InterData) {
                        // 処理なし
                    }
                }
            }
            return listener
        }
}

==> adfurikun-1.3.0.tar.gz: android/src/main/kotlin/jp/co/glossom/adfurikun/AdfurikunInterstitial.kt <==
package jp.co.glossom.adfurikun

import io.flutter.plugin.common.MethodChannel
import jp.tjkapp.adfurikunsdk.moviereward.*

/**
 * インタースティシャル
 */
internal class AdfurikunInterstitial(val number: Int, val appId: String, val channel: MethodChannel) {

    private var interstitial: AdfurikunInter? = null
    private var listener: AdfurikunInterListener? = null

    /**
     * 初期化
     */
    fun init() {
        if (AdfurikunPlugin.currentActivity != null) {
            interstitial = AdfurikunInter(appId, AdfurikunPlugin.currentActivity).apply {
                setAdfurikunInterListener(createListener)
            }
        }
    }

    /**
     * 読み込み
     */
    fun load() {
        interstitial?.load()
    }

    /**
     * 再生
     * @param customParams
     */
    fun play(customParams: HashMap<String, String>? = null) {
        interstitial?.play(customParams)
    }

    /**
     * 準備判定
     * @param result
     */
    fun isPrepared(result: MethodChannel.Result) {
        result.success(interstitial?.isPrepared ?: false)
    }

    /**
     * 破棄
     */
    fun destroy() {
        interstitial?.onDestroy()
        interstitial = null
        listener = null
    }

    /**
     * リスナーを作成
     */
    private val createListener: AdfurikunInterListener?
        get() {
            listener ?: run {
                listener = object : AdfurikunInterListener {
                    override fun onPrepareSuccess(isManualMode: Boolean) {
                        channel.invokeMethod(Constants.ON_PREPARE_SUCCESS, AdfurikunCommons.getArgs(number = number, appId = appId))
                    }

                    override fun onPrepareFailure(error: AdfurikunMovieError?) {
                        channel.invokeMethod(Constants.ON_PREPARE_FAILURE, AdfurikunCommons.getArgs(number = number, appId = appId, errorCode = error?.errorCode ?: 0))
                    }

                    override fun onStartPlaying(data: InterData) {
                        channel.invokeMethod(Constants.ON_START_PLAYING, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onFinishedPlaying(data: InterData) {
                        channel.invokeMethod(Constants.ON_FINISHED_PLAYING, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onFailedPlaying(data: InterData) {
                        channel.invokeMethod(Constants.ON_FAILED_PLAYING, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onAdClose(data: InterData) {
                        channel.invokeMethod(Constants.ON_AD_CLOSE, AdfurikunCommons.getArgs(number = number, appId = appId, adNetworkKey = data.adnetworkKey ?: ""))
                    }

                    override fun onStartShowing(data: InterData) {
                        // 処理なし
                    }

                    override fun onClick(data: InterData) {
                        // 処理なし
                    }
                }
            }
            return listener
        }
}
